@@ -216,27 +216,27 @@ def run_cat_report(output_dir, ticker, df):
         elif yy_rev_cat_corr > yy_rev_total_corr:
             yy_visuals_sheet.write("E2",yy_rev_cat_corr, beat_total_dollars_format)
         else:
-            yy_visuals_sheet.write("E2",yy_rev_cat_corr, border_format)
+            yy_visuals_sheet.write("E2",yy_rev_cat_corr, rounded_border_format)
         yy_visuals_sheet.write("F2", yy_rev_total_corr, rounded_border_format)
         yy_visuals_sheet.write("G2",yy_rev_est_corr, rounded_border_format)
         yy_visuals_sheet.write("H2", share_percs[yy_best_rev_cat], percent_border_format)
     else:
         yy_visuals_sheet.write("E2", "Unavailable", border_format)
-        yy_visuals_sheet.write("F2", "Unavailable", rounded_border_format)
-        yy_visuals_sheet.write("G2", "Unavailable", rounded_border_format)
-        yy_visuals_sheet.write("H2", "Unavailable", percent_border_format)
+        yy_visuals_sheet.write("F2", "Unavailable", border_format)
+        yy_visuals_sheet.write("G2", "Unavailable", border_format)
+        yy_visuals_sheet.write("H2", "Unavailable", border_format)
     
     if use_profit:
         if yy_profit_cat_corr > yy_profit_total_corr:
             yy_visuals_sheet.write("E3",yy_profit_cat_corr, beat_total_dollars_format)
         else:
-            yy_visuals_sheet.write("E3",yy_profit_cat_corr, border_format)
+            yy_visuals_sheet.write("E3",yy_profit_cat_corr, rounded_border_format)
         yy_visuals_sheet.write("F3", yy_profit_total_corr, rounded_border_format)
         yy_visuals_sheet.write("H3", share_percs[yy_best_profit_cat], percent_border_format)
     else:
         yy_visuals_sheet.write("E3", "Unavailable", border_format)
-        yy_visuals_sheet.write("F3", "Unavailable", rounded_border_format)
-        yy_visuals_sheet.write("H3", "Unavailable", percent_border_format)
+        yy_visuals_sheet.write("F3", "Unavailable", border_format)
+        yy_visuals_sheet.write("H3", "Unavailable", border_format)
     yy_visuals_sheet.write("G3", "N/A", border_format)
     
     if use_eps:
@@ -250,10 +250,10 @@ def run_cat_report(output_dir, ticker, df):
         yy_visuals_sheet.write("G4", yy_eps_est_corr, rounded_border_format)
         yy_visuals_sheet.write("H4", share_percs[yy_best_eps_cat], percent_border_format)
     else:
-        yy_visuals_sheet.write("E4", "Unavailable", rounded_border_format)
-        yy_visuals_sheet.write("F4", "Unavailable", rounded_border_format)
-        yy_visuals_sheet.write("G4", "Unavailable", rounded_border_format)
-        yy_visuals_sheet.write("H4", "Unavailable", percent_border_format)
+        yy_visuals_sheet.write("E4", "Unavailable", border_format)
+        yy_visuals_sheet.write("F4", "Unavailable", border_format)
+        yy_visuals_sheet.write("G4", "Unavailable", border_format)
+        yy_visuals_sheet.write("H4", "Unavailable", border_format)
 
 
     for col, size in {0:22, 1:29, 4:14, 5:18, 6:15, 7:18}.items():
@@ -262,16 +262,16 @@ def run_cat_report(output_dir, ticker, df):
     yy_x_axis = ["YY Data",1, yy_cols.index("quarter_end"), len(sdf_yy), yy_cols.index("quarter_end")]
 
     if use_rev:
-        yy_rev_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_rev_cat, REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
-        yy_rev_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
-        yy_rev_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_SALES", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy))
+        yy_rev_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_rev_cat, REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy), yy_rev_cat_corr)
+        yy_rev_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy), yy_rev_total_corr)
+        yy_rev_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_SALES", REVENUE_REPORT, "Reported Revenue", yy_x_axis, len(sdf_yy), yy_rev_est_corr)
     if use_profit:
-        yy_profit_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_profit_cat, PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy))
-        yy_profit_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy))
+        yy_profit_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_profit_cat, PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy), yy_profit_cat_corr)
+        yy_profit_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", PROFIT_REPORT, "Reported Profit", yy_x_axis, len(sdf_yy), yy_profit_total_corr)
     if use_eps:
-        yy_eps_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_eps_cat, EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
-        yy_eps_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
-        yy_eps_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_EPS", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy))
+        yy_eps_cat_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), yy_best_eps_cat, EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy), yy_eps_cat_corr)
+        yy_eps_total_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "total_dollars", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy), yy_eps_total_corr)
+        yy_eps_consenesus_chart = create_chart(workbook, "YY Data", list(sdf_yy.columns), "BEST_EPS", EPS_REPORT, "Reported EPS", yy_x_axis, len(sdf_yy), yy_eps_est_corr)
 
     if use_rev:
         yy_visuals_sheet.insert_chart("A6", yy_rev_cat_chart)
@@ -289,7 +289,7 @@ def run_cat_report(output_dir, ticker, df):
     writer.close()
         
 
-def create_chart(workbook, sheet_name, sheet_cols, npd_col, measure, measure_label, x_axis, num_rows):
+def create_chart(workbook, sheet_name, sheet_cols, npd_col, measure, measure_label, x_axis, num_rows, r_squared):
 
     npd_col_name = "Total NPD" if npd_col == "total_dollars" else npd_col
     chart = workbook.add_chart({"type":"line"})
@@ -298,10 +298,10 @@ def create_chart(workbook, sheet_name, sheet_cols, npd_col, measure, measure_lab
     chart.set_y_axis({"crossing":"min"})
     chart.set_x_axis({"name":"For Quarter Ending", "position_axis":"on_tick"})
     if npd_col == "total_dollars":
-        chart.set_title({"name":"YY Total NPD {measure} Correlation".format(measure=measure_label.replace("Reported ", ""))})
+        chart.set_title({"name":"YY Total NPD {measure} Correlation\nr{superscript} = {r_squared}".format(measure=measure_label.replace("Reported ", ""), superscript=chr(0x00b2), r_squared=round(r_squared, 3))})
     elif npd_col in ["BEST_SALES","BEST_EPS"]:
-        chart.set_title({"name":"YY Consensus {measure} Correlation".format(measure=measure_label.replace("Reported ", ""))})
+        chart.set_title({"name":"YY Consensus {measure} Correlation\nr{superscript} = {r_squared}".format(measure=measure_label.replace("Reported ", ""), superscript=chr(0x00b2), r_squared=round(r_squared, 3))})
     else:
-        chart.set_title({"name":"YY Category {measure} Correlation".format(measure=measure_label.replace("Reported ", ""))})
+        chart.set_title({"name":"YY Category {measure} Correlation\nr{superscript} = {r_squared}".format(measure=measure_label.replace("Reported ", ""), superscript=chr(0x00b2), r_squared=round(r_squared, 3))})
     chart.set_legend({"position":"bottom"})
     return chart
\ No newline at end of file
